@@ -37,7 +37,7 @@ void fx_login_free(FxLogin* fxlogin)
 //	free(fxlogin);
 }
 
-gboolean fx_login_proxy_button_func(GtkWidget *widget , GdkEventButton *event , gpointer data)
+gboolean fx_login_proxy_button_func(GtkWidget *UNUSED(widget) , GdkEventButton *event , gpointer data)
 {
 	FxLogin *fxlogin = (FxLogin*)data;
 	Proxy *proxy = fxlogin->proxy;
@@ -66,6 +66,8 @@ gboolean fx_login_proxy_button_func(GtkWidget *widget , GdkEventButton *event ,
 			gtk_dialog_run(GTK_DIALOG(fxproxy->dialog));
 			gtk_widget_destroy(fxproxy->dialog);
 			break;
+		default:
+			break;
 	}
 	return TRUE;
 }
@@ -116,7 +118,7 @@ void fx_login_initialize(FxMain* fxmain)
 
 	fxlogin->loginbutton = gtk_button_new_with_label("登录");
 
-	img = gtk_image_new_from_file(SKIN_DIR"move.gif");
+	img = gtk_image_new_from_file(SKIN_DIR"login.png");
 	gtk_button_set_image(GTK_BUTTON(fxlogin->loginbutton) , img);
 
 	fxlogin->loginFuncId = g_signal_connect(G_OBJECT(fxlogin->loginbutton)
@@ -187,7 +189,12 @@ void fx_login_initialize(FxMain* fxmain)
 	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->loginbutton , (WINDOW_WIDTH - 80)/2 , 270);
 	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->proxyBtn , (WINDOW_WIDTH - 100) / 2 , 320);
 	gtk_box_pack_start(GTK_BOX(fxmain->mainbox) , fxlogin->fixed , TRUE , TRUE , 0);
+
+	GTK_WIDGET_SET_FLAGS(fxlogin->loginbutton, GTK_CAN_DEFAULT);
+    gtk_widget_grab_default(fxlogin->loginbutton);
+
 	gtk_widget_show_all(fxmain->mainbox);
+
 }
 GtkTreeModel* fx_login_create_state_model()
 {
@@ -359,7 +366,6 @@ login:
 
 	/* download xml configuration file from the server */
 	fx_login_show_msg(fxlogin , "正在下载配置文件");
-	fetion_user_load(user);
 	fetion_config_download_configuration(user);
 	if(fetion_config_load_xml(user) < 0){
 		fx_login_show_msg(fxlogin , "登录失败");
@@ -390,7 +396,7 @@ login:
 	if(pos == NULL)
 	{
 		fx_login_show_msg(fxlogin , "登录失败");
-		return;
+		return NULL;
 	}
 	parse_sipc_reg_response(pos , &nonce , &key);
 	free(pos);
@@ -407,7 +413,7 @@ auth:
 	pos = sipc_aut_action(user , response);
 	if(pos == NULL){
 		fx_login_show_msg(fxlogin , "登录失败");
-		return;
+		return NULL;
 	}
 	if(parse_sipc_auth_response(pos , user) < 0){
 		debug_info("Password error , login failed!!!");
@@ -465,7 +471,7 @@ auth:
 		fetion_user_download_portrait(user , user->sipuri);
 		pb = gdk_pixbuf_new_from_file_at_size(iconPath , 48 , 48 , NULL);
 		if(pb == NULL){
-			pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.jpg" , 48 , 48 , NULL);
+			pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.png" , 48 , 48 , NULL);
 		}
 	}
 	notify_notification_update(fxmain->notify , "登录成功"// notifySummary
@@ -532,7 +538,7 @@ auth:
 	g_thread_exit(0);
 	return NULL;
 }
-void fx_login_action_func(GtkWidget* widget , gpointer data)
+void fx_login_action_func(GtkWidget* UNUSED(widget) , gpointer data)
 {
 	FxMain* fxmain = (FxMain*)data;
 	fxmain->loginPanel->loginThread = g_thread_create(fx_login_thread_func , fxmain , FALSE , NULL);
