@@ -75,7 +75,7 @@ static void show_search(GtkEntry *entry , gpointer data)
 	fx_search_initialize(search , model , text , x , y);
 }
 
-static void on_search_button_clicked(GtkEntry *entry , GtkEntryIconPosition *UNUSED(pos)
+static void on_search_button_clicked(GtkEntry *entry , void *UNUSED(pos)
 		, GdkEvent *UNUSED(event) , gpointer data)
 {
 	show_search(entry , data);
@@ -95,8 +95,10 @@ void fx_tree_initilize(FxMain* fxmain)
 	fxtree = fxmain->mainPanel;
 
 	fxtree->searchbox = gtk_entry_new();
+#ifdef gtk_entry_set_icon_from_stock
 	gtk_entry_set_icon_from_stock(GTK_ENTRY(fxtree->searchbox)
 			, GTK_ENTRY_ICON_SECONDARY , GTK_STOCK_FIND);
+#endif
 	g_signal_connect(fxtree->searchbox , "icon-press" , G_CALLBACK(on_search_button_clicked) , fxmain);
 	g_signal_connect(fxtree->searchbox , "activate" , G_CALLBACK(show_search) , fxmain);
 	gtk_widget_show_all(fxtree->searchbox);
